package com.glxp.udi.admin.controller.basic;

import com.github.pagehelper.PageInfo;
import com.glxp.udi.admin.annotation.AuthRuleAnnotation;
import com.glxp.udi.admin.constant.ConstantStatus;
import com.glxp.udi.admin.entity.basic.BasicThirdSysDetailEntity;
import com.glxp.udi.admin.entity.basic.BasicThirdSysEntity;
import com.glxp.udi.admin.entity.basic.BasicUnitMaintainEntity;
import com.glxp.udi.admin.entity.info.CompanyEntity;
import com.glxp.udi.admin.entity.inout.OrderEntity;
import com.glxp.udi.admin.entity.param.SystemParamConfigEntity;
import com.glxp.udi.admin.entity.thrsys.ThrCorpEntity;
import com.glxp.udi.admin.httpclient.ErpBasicClient;
import com.glxp.udi.admin.req.basic.*;
import com.glxp.udi.admin.req.info.DeleteRequest;
import com.glxp.udi.admin.req.inout.OrderFilterRequest;
import com.glxp.udi.admin.req.thrsys.FilterThrCorpRequest;
import com.glxp.udi.admin.res.PageSimpleResponse;
import com.glxp.udi.admin.res.basic.BasicProductThirdSysResponse;
import com.glxp.udi.admin.res.basic.BasicUnitMaintainResponse;
import com.glxp.udi.admin.res.basic.ErpUnitsResponse;
import com.glxp.udi.admin.service.basic.BasicThirdSysDetailService;
import com.glxp.udi.admin.service.basic.BasicThirdSysService;
import com.glxp.udi.admin.service.basic.BasicUnitMaintainService;
import com.glxp.udi.admin.service.info.CompanyService;
import com.glxp.udi.admin.service.inout.OrderService;
import com.glxp.udi.admin.service.param.SystemParamConfigService;
import com.glxp.udi.admin.service.thrsys.ThrCorpService;
import com.glxp.udi.admin.thread.BasicUnitImportService;
import com.glxp.udi.admin.util.CustomUtil;
import com.glxp.udi.common.enums.ResultEnum;
import com.glxp.udi.common.res.BaseResponse;
import com.glxp.udi.common.util.ResultVOUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.BeanUtils;
import org.springframework.validation.BindingResult;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import javax.validation.Valid;
import java.util.*;
import java.util.stream.Collectors;

/**
 * 往来单位信息维护
 */
@RestController
public class BasicUnitMaintainController {

    @Resource
    private BasicUnitMaintainService basicUnitMaintainService;
    @Resource
    BasicThirdSysDetailService basicThirdSysDetailService;
    @Resource
    private SystemParamConfigService systemParamConfigService;
    @Resource
    private BasicThirdSysService basicThirdSysService;
    @Resource
    BasicUnitImportService basicUnitImportService;
    @Resource
    private ThrCorpService thrCorpService;
    @Resource
    private CompanyService companyService;
    @Resource
    private OrderService orderService;
    @Resource
    private ErpBasicClient erpBasicClient;

    @GetMapping("/udiwms/basic/unit/maintain/filter")
    public BaseResponse filterBasicUnitMaintain(BasicUnitMaintainFilterRequest basicUnitMaintainFilterRequest,
                                                BindingResult bindingResult) {

        if (bindingResult.hasErrors()) {
            return ResultVOUtils.error(ResultEnum.PARAM_VERIFY_FALL, bindingResult.getFieldError().getDefaultMessage());
        }
        List<BasicUnitMaintainEntity> basicUnitMaintainEntities;
        basicUnitMaintainFilterRequest.setOutType(ConstantStatus.CORP_SICK_SICK);
        basicUnitMaintainEntities = basicUnitMaintainService.filterList(basicUnitMaintainFilterRequest);
        PageInfo<BasicUnitMaintainEntity> pageInfo = new PageInfo<>(basicUnitMaintainEntities);
        PageSimpleResponse<BasicUnitMaintainEntity> pageSimpleResponse = new PageSimpleResponse<>();
        pageSimpleResponse.setTotal(pageInfo.getTotal());
        pageSimpleResponse.setList(basicUnitMaintainEntities);

        SystemParamConfigEntity systemParamConfigEntityBUMErpId = systemParamConfigService.selectByParamKey("basic_unit_maintain_erp_id");
        SystemParamConfigEntity systemParamConfigEntityBUMThirdId = systemParamConfigService.selectByParamKey("basic_cops_thirdSys");
        Map<String, Object> rMap = new HashMap<>();
        rMap.put("BUMErpIdValue",
                systemParamConfigEntityBUMErpId != null && StringUtils.isNotBlank(systemParamConfigEntityBUMErpId.getParamValue()) ?
                        systemParamConfigEntityBUMErpId.getParamValue() : "0");
        rMap.put("BUMThirdIdValue",
                systemParamConfigEntityBUMThirdId != null && StringUtils.isNotBlank(systemParamConfigEntityBUMThirdId.getParamValue()) ?
                        systemParamConfigEntityBUMThirdId.getParamValue() : "0");
        rMap.put("page", pageSimpleResponse);
        return ResultVOUtils.success(rMap);
    }

    @GetMapping("/udiwms/basic/unit/maintain/filter2")
    public BaseResponse filterBasicUnitMaintain2(BasicUnitMaintainFilterRequest basicUnitMaintainFilterRequest,
                                                 BindingResult bindingResult) {

        if (bindingResult.hasErrors()) {
            return ResultVOUtils.error(ResultEnum.PARAM_VERIFY_FALL, bindingResult.getFieldError().getDefaultMessage());
        }
        List<BasicUnitMaintainEntity> basicUnitMaintainEntities;
        basicUnitMaintainEntities = basicUnitMaintainService.filterList(basicUnitMaintainFilterRequest);
        PageInfo<BasicUnitMaintainEntity> pageInfo;
        pageInfo = new PageInfo<>(basicUnitMaintainEntities);
        PageSimpleResponse<BasicUnitMaintainEntity> pageSimpleResponse = new PageSimpleResponse<>();
        pageSimpleResponse.setTotal(pageInfo.getTotal());
        pageSimpleResponse.setList(basicUnitMaintainEntities);
        return ResultVOUtils.success(pageSimpleResponse);
    }

    @AuthRuleAnnotation("")
    @PostMapping("/udiwms/basic/unit/maintain/save")
    public BaseResponse save(@RequestBody @Valid BasicUnitMaintainEntity basicUnitMaintainSaveRequest,
                             BindingResult bindingResult) {

        if (bindingResult.hasErrors()) {
            return ResultVOUtils.error(ResultEnum.PARAM_VERIFY_FALL, bindingResult.getFieldError().getDefaultMessage());
        }

        BasicUnitMaintainEntity basicUnitMaintainEntity = new BasicUnitMaintainEntity();
        BeanUtils.copyProperties(basicUnitMaintainSaveRequest, basicUnitMaintainEntity);
        basicUnitMaintainEntity.setErpId(CustomUtil.getId());
        basicUnitMaintainEntity.setOutType(ConstantStatus.CORP_SICK_CUS);
        boolean b = basicUnitMaintainService.insertBasicUnitMaintain(basicUnitMaintainEntity);
        if (!b) {
            return ResultVOUtils.error(ResultEnum.NOT_NETWORK);
        }

        return ResultVOUtils.success();
    }

    @AuthRuleAnnotation("")
    @PostMapping("/udiwms/basic/unit/maintain/update")
    public BaseResponse update(@RequestBody BasicUnitMaintainEntity basicUnitMaintainSaveRequest) {
        basicUnitMaintainService.updateById(basicUnitMaintainSaveRequest);
        return ResultVOUtils.success("修改成功");
    }

    @AuthRuleAnnotation("")
    @GetMapping("/udiwms/unit/download")
    public BaseResponse downloadBasicUnit(BasicUnitMaintainFilterRequest basicUnitMaintainFilterRequest,
                                          BindingResult bindingResult) {

        if (bindingResult.hasErrors()) {
            return ResultVOUtils.error(ResultEnum.PARAM_VERIFY_FALL, bindingResult.getFieldError().getDefaultMessage());
        }
        List<BasicUnitMaintainEntity> basicUnitMaintainEntities;
        basicUnitMaintainEntities = basicUnitMaintainService.filterList(basicUnitMaintainFilterRequest);

        List<BasicUnitMaintainResponse> basicUnitMaintainResponses = basicUnitMaintainEntities.stream().map(item ->
        {
            BasicUnitMaintainResponse basicUnitMaintainResponse = new BasicUnitMaintainResponse();
            BeanUtils.copyProperties(item, basicUnitMaintainResponse);
            basicUnitMaintainResponse.setUnitId(item.getErpId());
            return basicUnitMaintainResponse;
        }).collect(Collectors.toList());
        PageInfo<BasicUnitMaintainResponse> pageInfo;
        pageInfo = new PageInfo<>(basicUnitMaintainResponses);
        PageSimpleResponse<BasicUnitMaintainResponse> pageSimpleResponse = new PageSimpleResponse<>();
        pageSimpleResponse.setTotal(pageInfo.getTotal());
        pageSimpleResponse.setList(basicUnitMaintainResponses);
        return ResultVOUtils.success(pageSimpleResponse);
    }

    @AuthRuleAnnotation("")
    @PostMapping("/udiwms/basic/unit/maintain/combine")
    public BaseResponse combine(@RequestBody CombineUnitRequest combineRequest, BindingResult bindingResult) {

        if (bindingResult.hasErrors()) {
            return ResultVOUtils.error(ResultEnum.PARAM_VERIFY_FALL, bindingResult.getFieldError().getDefaultMessage());
        }
        List<ErpUnitsResponse> erpUnitsResponses = combineRequest.getCustmandocResponses();
        if (erpUnitsResponses != null && erpUnitsResponses.size() > 0) {
            for (ErpUnitsResponse erpUnitsResponse : erpUnitsResponses) {
                BasicUnitMaintainEntity basicUnitMaintainEntity = new BasicUnitMaintainEntity();
                if (combineRequest.getThirdSys() != null) {
                    if ("thirdId".equals(combineRequest.getThirdSys())) {
                        basicUnitMaintainEntity.setThirdId(erpUnitsResponse.getId());
                        basicUnitMaintainEntity.setThirdName(erpUnitsResponse.getName());
                    } else if ("thirdId1".equals(combineRequest.getThirdSys())) {
                        basicUnitMaintainEntity.setThirdId1(erpUnitsResponse.getId());
                        basicUnitMaintainEntity.setThirdName1(erpUnitsResponse.getName());
                    } else if ("thirdId2".equals(combineRequest.getThirdSys())) {
                        basicUnitMaintainEntity.setThirdId2(erpUnitsResponse.getId());
                        basicUnitMaintainEntity.setThirdName2(erpUnitsResponse.getName());
                    } else if ("thirdId3".equals(combineRequest.getThirdSys())) {
                        basicUnitMaintainEntity.setThirdId3(erpUnitsResponse.getId());
                        basicUnitMaintainEntity.setThirdName3(erpUnitsResponse.getName());
                    } else if ("thirdId4".equals(combineRequest.getThirdSys())) {
                        basicUnitMaintainEntity.setThirdId4(erpUnitsResponse.getId());
                        basicUnitMaintainEntity.setThirdName4(erpUnitsResponse.getName());
                    }
                }
                basicUnitMaintainEntity.setErpId(CustomUtil.getId());
                basicUnitMaintainEntity.setName(erpUnitsResponse.getName());
                basicUnitMaintainEntity.setSpell(erpUnitsResponse.getSpell());
                basicUnitMaintainEntity.setAddr(erpUnitsResponse.getAddr());
                basicUnitMaintainEntity.setCreditNo(erpUnitsResponse.getCreditNo());
                basicUnitMaintainEntity.setContact(erpUnitsResponse.getContact());
                basicUnitMaintainEntity.setMobile(erpUnitsResponse.getMobile());
                basicUnitMaintainEntity.setCorpType(ConstantStatus.CORP_SP);
                basicUnitMaintainEntity.setUpdateTime(new Date());
                basicUnitMaintainService.insertBasicUnitMaintain(basicUnitMaintainEntity);
            }
        }
        return ResultVOUtils.success("选入成功");
    }

    @AuthRuleAnnotation("")
    @GetMapping("/udiwms/basic/unit/maintain/combineAll")
    public BaseResponse combineAll(BasicUnitMaintainFilterRequest unitMaintainFilterRequest, BindingResult bindingResult) {

        if (bindingResult.hasErrors()) {
            return ResultVOUtils.error(ResultEnum.PARAM_VERIFY_FALL, bindingResult.getFieldError().getDefaultMessage());
        }
        BasicThirdSysDetailEntity basicThirdSysDetailEntity = basicThirdSysDetailService.selectByKey("corpUrl", unitMaintainFilterRequest.getThirdSys());
        if (basicThirdSysDetailEntity == null || basicThirdSysDetailEntity.getValue() == null)
            return ResultVOUtils.error(500, "往来单位接口地址未定义");
        if (basicThirdSysDetailEntity.getEnabled()) {
            basicUnitImportService.selectAllUnit(basicThirdSysDetailEntity, unitMaintainFilterRequest);

        } else {
            return ResultVOUtils.error(500, "第三方往来单位服务未启用");
        }


        return ResultVOUtils.success("后台正在添加，请稍后刷新查看！");
    }

    @AuthRuleAnnotation("")
    @PostMapping("/udiwms/basic/unit/maintain/combineSingle")
    public BaseResponse combineSingle(@RequestBody CombineSingleUnitRequest combineRequest, BindingResult bindingResult) {

        if (bindingResult.hasErrors()) {
            return ResultVOUtils.error(ResultEnum.PARAM_VERIFY_FALL, bindingResult.getFieldError().getDefaultMessage());
        }
        ErpUnitsResponse erpUnitsResponse = combineRequest.getErpUnitsResponse();
        BasicUnitMaintainEntity basicUnitMaintainEntity = new BasicUnitMaintainEntity();
        basicUnitMaintainEntity.setId(Integer.parseInt(combineRequest.getKey()));
        if (combineRequest.getThirdSys() != null) {
            if ("thirdId".equals(combineRequest.getThirdSys())) {
                basicUnitMaintainEntity.setThirdId(erpUnitsResponse.getId());
                basicUnitMaintainEntity.setThirdName(erpUnitsResponse.getName());
            } else if ("thirdId1".equals(combineRequest.getThirdSys())) {
                basicUnitMaintainEntity.setThirdId1(erpUnitsResponse.getId());
                basicUnitMaintainEntity.setThirdName1(erpUnitsResponse.getName());
            } else if ("thirdId2".equals(combineRequest.getThirdSys())) {
                basicUnitMaintainEntity.setThirdId2(erpUnitsResponse.getId());
                basicUnitMaintainEntity.setThirdName2(erpUnitsResponse.getName());
            } else if ("thirdId3".equals(combineRequest.getThirdSys())) {
                basicUnitMaintainEntity.setThirdId3(erpUnitsResponse.getId());
                basicUnitMaintainEntity.setThirdName3(erpUnitsResponse.getName());
            } else if ("thirdId4".equals(combineRequest.getThirdSys())) {
                basicUnitMaintainEntity.setThirdId4(erpUnitsResponse.getId());
                basicUnitMaintainEntity.setThirdName4(erpUnitsResponse.getName());
            }
        }
//        basicUnitMaintainEntity.setThirdName(erpUnitsResponse.getName());
//        basicUnitMaintainEntity.setSpell(erpUnitsResponse.getSpell());
//        basicUnitMaintainEntity.setAddr(erpUnitsResponse.getAddr());
//        basicUnitMaintainEntity.setCreditNo(erpUnitsResponse.getCreditNo());
//        basicUnitMaintainEntity.setContact(erpUnitsResponse.getContact());
//        basicUnitMaintainEntity.setMobile(erpUnitsResponse.getMobile());
        basicUnitMaintainService.updateById(basicUnitMaintainEntity);
        return ResultVOUtils.success("关联成功");
    }

    //解除绑定
    @AuthRuleAnnotation("")
    @GetMapping("/udiwms/unit/thirdSys/removeRl")
    public BaseResponse uploadThirdServcie(RemoveRelRequest removeRelRequest) {
        BasicUnitMaintainEntity udiRelevanceEntity = basicUnitMaintainService.selectById(removeRelRequest.getRelId());
        if (removeRelRequest.getThirdSys().equals("thirdId")) {
            udiRelevanceEntity.setThirdId("");
            udiRelevanceEntity.setThirdName("");
        } else if (removeRelRequest.getThirdSys().equals("thirdId1")) {
            udiRelevanceEntity.setThirdId1("");
            udiRelevanceEntity.setThirdName1("");
        } else if (removeRelRequest.getThirdSys().equals("thirdId2")) {
            udiRelevanceEntity.setThirdId2("");
            udiRelevanceEntity.setThirdName2("");
        } else if (removeRelRequest.getThirdSys().equals("thirdId3")) {
            udiRelevanceEntity.setThirdId3("");
            udiRelevanceEntity.setThirdName3("");
        } else if (removeRelRequest.getThirdSys().equals("thirdId4")) {
            udiRelevanceEntity.setThirdId4("");
            udiRelevanceEntity.setThirdName4("");
        }
        basicUnitMaintainService.updateById(udiRelevanceEntity);

        return ResultVOUtils.success("解除绑定成功！");
    }

    @AuthRuleAnnotation("")
    @PostMapping("/udiwms/basic/unit/maintain/delete")
    public BaseResponse deleteBasicUnitMaintain(@RequestBody DeleteRequest deleteRequest, BindingResult bindingResult) {

        if (bindingResult.hasErrors()) {
            return ResultVOUtils.error(ResultEnum.PARAM_VERIFY_FALL, bindingResult.getFieldError().getDefaultMessage());
        }
        String id = deleteRequest.getId();
        BasicUnitMaintainEntity basicUnitMaintainEntity = basicUnitMaintainService.selectById(id);

        //判断是否被单据绑定
        OrderFilterRequest orderFilterRequest = new OrderFilterRequest();
        orderFilterRequest.setFromCorpId(basicUnitMaintainEntity.getErpId());
        OrderEntity orderEntity = orderService.findOne(orderFilterRequest);
        if (orderEntity != null) {
            return ResultVOUtils.error(500, "已存在该供应商单据，无法删除!");
        }
        //判断供应商是否已存在
        CompanyEntity companyEntity = companyService.findCompanyByUnitFk(basicUnitMaintainEntity.getErpId());
        if (companyEntity != null) {
            return ResultVOUtils.error(500, "供应商已注册，无法删除!");
        }

        basicUnitMaintainService.deleteById(id);
        return ResultVOUtils.success("删除成功");
    }

    //查询ERP往来单位
    @AuthRuleAnnotation("")
    @GetMapping("/udiwms/unitMaintain/filterErp")
    public BaseResponse filterErp(BasicUnitMaintainFilterRequest unitMaintainFilterRequest,
                                  BindingResult bindingResult) {

        if (bindingResult.hasErrors()) {
            return ResultVOUtils.error(ResultEnum.PARAM_VERIFY_FALL, bindingResult.getFieldError().getDefaultMessage());
        }
        BasicThirdSysDetailEntity basicThirdSysDetailEntity = basicThirdSysDetailService.selectByKey("corpUrl", unitMaintainFilterRequest.getThirdSys());
        if (basicThirdSysDetailEntity == null || basicThirdSysDetailEntity.getValue() == null)
            return ResultVOUtils.error(500, "往来单位接口地址未定义");
        if (basicThirdSysDetailEntity.getEnabled()) {
            if (basicThirdSysDetailEntity.getFromType() == 0 || (unitMaintainFilterRequest.getIsDownThrSys() != null && unitMaintainFilterRequest.getIsDownThrSys())) {
                BaseResponse<PageSimpleResponse<ErpUnitsResponse>> udiDlDeviceResponse =
                        erpBasicClient.getErpCrop(unitMaintainFilterRequest, basicThirdSysDetailEntity.getValue());

                if (udiDlDeviceResponse.getCode() == 20000) {
                    for (ErpUnitsResponse erpUnitsResponse : udiDlDeviceResponse.getData().getList()) {
                        BasicUnitMaintainEntity basicUnitMaintainEntity = basicUnitMaintainService.selectByThirdId(erpUnitsResponse.getId(), unitMaintainFilterRequest.getThirdSys());
                        if (basicUnitMaintainEntity != null) {
                            erpUnitsResponse.setChecked(true);
                        } else {
                            erpUnitsResponse.setChecked(false);
                        }
                    }

                    return udiDlDeviceResponse;
                } else {
                    return udiDlDeviceResponse;
                }

            } else {
                FilterThrCorpRequest filterThrCorpRequest = new FilterThrCorpRequest();
                BeanUtils.copyProperties(unitMaintainFilterRequest, filterThrCorpRequest);
                filterThrCorpRequest.setThirdSysFk(unitMaintainFilterRequest.getThirdSys());
                List<ThrCorpEntity> thrCorpEntities
                        = thrCorpService.filterThrCorps(filterThrCorpRequest);
                List<ThrCorpEntity> thrCorpEntityList = thrCorpEntities.stream().map(item ->
                {
                    ThrCorpEntity thrCorpEntity = new ThrCorpEntity();
                    BeanUtils.copyProperties(item, thrCorpEntity);
                    BasicUnitMaintainEntity basicUnitMaintainEntity = basicUnitMaintainService.selectByThirdId(item.getUnitId(), unitMaintainFilterRequest.getThirdSys());
                    if (basicUnitMaintainEntity != null) {
                        thrCorpEntity.setChecked(true);
                    } else {
                        thrCorpEntity.setChecked(false);
                    }
                    thrCorpEntity.setId(item.getUnitId());
                    return thrCorpEntity;
                }).collect(Collectors.toList());
                PageInfo<ThrCorpEntity> pageInfo;
                pageInfo = new PageInfo<>(thrCorpEntities);
                PageSimpleResponse<ThrCorpEntity> pageSimpleResponse = new PageSimpleResponse<>();
                pageSimpleResponse.setTotal(pageInfo.getTotal());
                pageSimpleResponse.setList(thrCorpEntityList);
                return ResultVOUtils.success(pageSimpleResponse);
            }
        } else {
            return ResultVOUtils.error(500, "第三方往来单位服务未启用");
        }


    }

    //获取产品信息详情（多平台）
    @AuthRuleAnnotation("")
    @GetMapping("/udiwms/unitMaintain/thirdSys/detail")
    public BaseResponse getThirdSysDetail(BasicUnitMaintainFilterRequest basicUnitMaintainFilterRequest,
                                          BindingResult bindingResult) {

        if (bindingResult.hasErrors()) {
            return ResultVOUtils.error(ResultEnum.PARAM_VERIFY_FALL, bindingResult.getFieldError().getDefaultMessage());
        }
        BasicUnitMaintainEntity basicUnitMaintainEntity = basicUnitMaintainService.selectById(basicUnitMaintainFilterRequest.getId() + "");

        FilterBasicThirdSysRequest filterBasicThirdSysRequest = new FilterBasicThirdSysRequest();
        filterBasicThirdSysRequest.setEnabled(true);
        List<BasicThirdSysEntity> basicThirdSysEntities = basicThirdSysService.filterBasicThiSys(filterBasicThirdSysRequest);
        List<BasicProductThirdSysResponse> basicProductThirdSysResponses = new ArrayList<>();

        for (BasicThirdSysEntity basicThirdSysEntity : basicThirdSysEntities) {
            if (basicThirdSysEntity.getThirdId().equals("thirdId")) {
                BasicProductThirdSysResponse basicProductThirdSysResponse = new BasicProductThirdSysResponse();
                basicProductThirdSysResponse.setSysId(basicThirdSysEntity.getThirdId());
                basicProductThirdSysResponse.setSysName(basicThirdSysEntity.getThirdName());
                if (basicUnitMaintainEntity != null) {
                    basicProductThirdSysResponse.setThirdId(basicUnitMaintainEntity.getThirdId());
                    basicProductThirdSysResponse.setThirdName(basicUnitMaintainEntity.getThirdName());
                }

                basicProductThirdSysResponses.add(basicProductThirdSysResponse);
            } else if (basicThirdSysEntity.getThirdId().equals("thirdId1")) {
                BasicProductThirdSysResponse basicProductThirdSysResponse = new BasicProductThirdSysResponse();
                basicProductThirdSysResponse.setSysId(basicThirdSysEntity.getThirdId());
                basicProductThirdSysResponse.setSysName(basicThirdSysEntity.getThirdName());
                if (basicUnitMaintainEntity != null) {
                    basicProductThirdSysResponse.setThirdId(basicUnitMaintainEntity.getThirdId1());
                    basicProductThirdSysResponse.setThirdName(basicUnitMaintainEntity.getThirdName1());
                }
                basicProductThirdSysResponses.add(basicProductThirdSysResponse);
            } else if (basicThirdSysEntity.getThirdId().equals("thirdId2")) {
                BasicProductThirdSysResponse basicProductThirdSysResponse = new BasicProductThirdSysResponse();
                basicProductThirdSysResponse.setSysId(basicThirdSysEntity.getThirdId());
                basicProductThirdSysResponse.setSysName(basicThirdSysEntity.getThirdName());
                if (basicUnitMaintainEntity != null) {
                    basicProductThirdSysResponse.setThirdId(basicUnitMaintainEntity.getThirdId2());
                    basicProductThirdSysResponse.setThirdName(basicUnitMaintainEntity.getThirdName2());
                }
                basicProductThirdSysResponses.add(basicProductThirdSysResponse);
            } else if (basicThirdSysEntity.getThirdId().equals("thirdId3")) {
                BasicProductThirdSysResponse basicProductThirdSysResponse = new BasicProductThirdSysResponse();
                basicProductThirdSysResponse.setSysId(basicThirdSysEntity.getThirdId());
                basicProductThirdSysResponse.setSysName(basicThirdSysEntity.getThirdName());
                if (basicUnitMaintainEntity != null) {
                    basicProductThirdSysResponse.setThirdId(basicUnitMaintainEntity.getThirdId3());
                    basicProductThirdSysResponse.setThirdName(basicUnitMaintainEntity.getThirdName3());
                }
                basicProductThirdSysResponses.add(basicProductThirdSysResponse);
            } else if (basicThirdSysEntity.getThirdId().equals("thirdId4")) {
                BasicProductThirdSysResponse basicProductThirdSysResponse = new BasicProductThirdSysResponse();
                basicProductThirdSysResponse.setSysId(basicThirdSysEntity.getThirdId());
                basicProductThirdSysResponse.setSysName(basicThirdSysEntity.getThirdName());
                if (basicUnitMaintainEntity != null) {
                    basicProductThirdSysResponse.setThirdId(basicUnitMaintainEntity.getThirdId4());
                    basicProductThirdSysResponse.setThirdName(basicUnitMaintainEntity.getThirdName4());
                }
                basicProductThirdSysResponses.add(basicProductThirdSysResponse);
            }
        }
        PageInfo<BasicProductThirdSysResponse> pageInfo;
        pageInfo = new PageInfo<>(basicProductThirdSysResponses);
        PageSimpleResponse<BasicProductThirdSysResponse> pageSimpleResponse = new PageSimpleResponse<>();
        pageSimpleResponse.setTotal(pageInfo.getTotal());
        pageSimpleResponse.setList(basicProductThirdSysResponses);
        return ResultVOUtils.success(pageSimpleResponse);
    }

    public BasicThirdSysEntity filterThirdSys(String thirdId, List<BasicThirdSysEntity> basicThirdSysEntities) {
        if (basicThirdSysEntities != null && basicThirdSysEntities.size() > 0) {
            for (BasicThirdSysEntity basicThirdSysEntity : basicThirdSysEntities) {
                if (thirdId.equals(basicThirdSysEntity.getThirdId())) {
                    return basicThirdSysEntity;
                }
            }
        }
        return null;
    }
}
