package com.glxp.udi.admin.controller.basic;

import cn.hutool.core.util.StrUtil;
import com.alibaba.fastjson.JSON;
import com.github.pagehelper.PageInfo;
import com.glxp.udi.admin.annotation.AuthRuleAnnotation;
import com.glxp.udi.admin.constant.Constant;
import com.glxp.udi.admin.constant.ConstantType;
import com.glxp.udi.admin.entity.auth.AuthAdmin;
import com.glxp.udi.admin.entity.basic.BussinessLocalTypeEntity;
import com.glxp.udi.admin.entity.basic.BussinessTypeEntity;
import com.glxp.udi.admin.entity.basic.CndidateRequest;
import com.glxp.udi.admin.entity.inout.OrderEntity;
import com.glxp.udi.admin.exception.JsonException;
import com.glxp.udi.admin.req.basic.BussinessTypeFilterRequest;
import com.glxp.udi.admin.req.info.DeleteRequest;
import com.glxp.udi.admin.req.inout.OrderFilterRequest;
import com.glxp.udi.admin.res.PageSimpleResponse;
import com.glxp.udi.admin.res.basic.BussinessTypResponse;
import com.glxp.udi.admin.service.auth.AuthAdminService;
import com.glxp.udi.admin.service.auth.CustomerService;
import com.glxp.udi.admin.service.basic.BussinessLocalTypeService;
import com.glxp.udi.admin.service.basic.BussinessTypeService;
import com.glxp.udi.admin.service.inout.OrderService;
import com.glxp.udi.admin.util.CustomUtil;
import com.glxp.udi.admin.util.FileUtils;
import com.glxp.udi.common.enums.ResultEnum;
import com.glxp.udi.common.res.BaseResponse;
import com.glxp.udi.common.util.ResultVOUtils;
import org.springframework.validation.BindingResult;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.context.request.RequestContextHolder;
import org.springframework.web.context.request.ServletRequestAttributes;
import org.springframework.web.multipart.MultipartFile;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.io.InputStream;
import java.util.List;

/**
 * 业务类型维护
 */

@RestController
public class BussinessTypeController {


    @Resource
    private BussinessTypeService bussinessTypeService;
    @Resource
    private BussinessLocalTypeService bussinessLocalTypeService;
    @Resource
    private AuthAdminService authAdminService;
    @Resource
    private OrderService orderService;
    @Resource
    CustomerService customerService;

    @AuthRuleAnnotation("")
    @GetMapping("/udiwms/bussinessType/filter")
    public BaseResponse filterBussinessType(BussinessTypeFilterRequest bussinessTypeFilterRequest,
                                            BindingResult bindingResult) {

        if (bindingResult.hasErrors()) {
            return ResultVOUtils.error(ResultEnum.PARAM_VERIFY_FALL, bindingResult.getFieldError().getDefaultMessage());
        }
        String customerId = getCustomerId();
        if (!customerId.equals(Constant.SYSTEM_CUSTOMER_ID)) {
            bussinessTypeFilterRequest.setSpUse(true);
        }
        List<BussinessTypeEntity> bussinessTypeEntities;
        bussinessTypeEntities = bussinessTypeService.filterList(bussinessTypeFilterRequest);
        PageInfo<BussinessTypeEntity> pageInfo;
        pageInfo = new PageInfo<>(bussinessTypeEntities);
        PageSimpleResponse<BussinessTypeEntity> pageSimpleResponse = new PageSimpleResponse<>();
        pageSimpleResponse.setTotal(pageInfo.getTotal());
        pageSimpleResponse.setList(bussinessTypeEntities);
        return ResultVOUtils.success(pageSimpleResponse);
    }

    @AuthRuleAnnotation("")
    @GetMapping("/udiwms/bussinessType/joinFilter")
    public BaseResponse filterJoinBussinessType(BussinessTypeFilterRequest bussinessTypeFilterRequest,
                                                BindingResult bindingResult) {

        if (bindingResult.hasErrors()) {
            return ResultVOUtils.error(ResultEnum.PARAM_VERIFY_FALL, bindingResult.getFieldError().getDefaultMessage());
        }
        String customerId = getCustomerId();
        if (!customerId.equals(Constant.SYSTEM_CUSTOMER_ID)) {
            bussinessTypeFilterRequest.setSpUse(true);
        }

        if (!StrUtil.isEmpty(bussinessTypeFilterRequest.getFilterAction())) {
            BussinessLocalTypeEntity bussinessLocalTypeEntity = bussinessLocalTypeService.findBTByAction(bussinessTypeFilterRequest.getFilterAction());
            if (bussinessLocalTypeEntity.getMainAction().equals(ConstantType.TYPE_PUT)) {
                bussinessTypeFilterRequest.setMainAction(ConstantType.TYPE_OUT);
            } else {
                bussinessTypeFilterRequest.setMainAction(ConstantType.TYPE_PUT);
            }

            bussinessTypeFilterRequest.setAdvanceType(bussinessLocalTypeEntity.isAdvanceType());
        }


        List<BussinessTypResponse> bussinessTypeEntities;
        bussinessTypeEntities = bussinessTypeService.filterJoinList(bussinessTypeFilterRequest);
        PageInfo<BussinessTypResponse> pageInfo;
        pageInfo = new PageInfo<>(bussinessTypeEntities);
        PageSimpleResponse<BussinessTypResponse> pageSimpleResponse = new PageSimpleResponse<>();
        pageSimpleResponse.setTotal(pageInfo.getTotal());
        pageSimpleResponse.setList(bussinessTypeEntities);
        return ResultVOUtils.success(pageSimpleResponse);
    }

    @AuthRuleAnnotation("")
    @GetMapping("/udiwms/bussinessType/filterAllByUser")
    public BaseResponse filterAllByUser(BussinessTypeFilterRequest bussinessTypeFilterRequest,
                                        BindingResult bindingResult) {

        if (bindingResult.hasErrors()) {
            return ResultVOUtils.error(ResultEnum.PARAM_VERIFY_FALL, bindingResult.getFieldError().getDefaultMessage());
        }
        String customerId = getCustomerId();
        if (!customerId.equals(Constant.SYSTEM_CUSTOMER_ID)) {
            bussinessTypeFilterRequest.setSpUse(true);
        } else {
            bussinessTypeFilterRequest.setUserId(customerService.getUserId());
        }
        List<BussinessTypeEntity> bussinessTypeEntities;
        bussinessTypeEntities = bussinessTypeService.filterAllByUser(bussinessTypeFilterRequest);
        PageInfo<BussinessTypeEntity> pageInfo;
        pageInfo = new PageInfo<>(bussinessTypeEntities);
        PageSimpleResponse<BussinessTypeEntity> pageSimpleResponse = new PageSimpleResponse<>();
        pageSimpleResponse.setTotal(pageInfo.getTotal());
        pageSimpleResponse.setList(bussinessTypeEntities);
        return ResultVOUtils.success(pageSimpleResponse);
    }


    @GetMapping("/udiwms/bussinessType/udimsFilter")
    public BaseResponse udimsFilter(BussinessTypeFilterRequest bussinessTypeFilterRequest,
                                    BindingResult bindingResult) {

        if (bindingResult.hasErrors()) {
            return ResultVOUtils.error(ResultEnum.PARAM_VERIFY_FALL, bindingResult.getFieldError().getDefaultMessage());
        }
        bussinessTypeFilterRequest.setSpUse(true);
        List<BussinessTypResponse> bussinessTypeEntities;
        bussinessTypeEntities = bussinessTypeService.filterJoinList(bussinessTypeFilterRequest);
        PageInfo<BussinessTypResponse> pageInfo;
        pageInfo = new PageInfo<>(bussinessTypeEntities);
        PageSimpleResponse<BussinessTypResponse> pageSimpleResponse = new PageSimpleResponse<>();
        pageSimpleResponse.setTotal(pageInfo.getTotal());
        pageSimpleResponse.setList(bussinessTypeEntities);
        return ResultVOUtils.success(pageSimpleResponse);
    }


    @AuthRuleAnnotation("")
    @PostMapping("/udiwms/bussinessType/delete")
    public BaseResponse deleteBussinessType(@RequestBody DeleteRequest deleteRequest, BindingResult bindingResult) {

        if (bindingResult.hasErrors()) {
            return ResultVOUtils.error(ResultEnum.PARAM_VERIFY_FALL, bindingResult.getFieldError().getDefaultMessage());
        }
        String id = deleteRequest.getId();
        BussinessTypeEntity bussinessTypeEntity = bussinessTypeService.selectById(id);
        OrderFilterRequest orderFilterRequest = new OrderFilterRequest();
        orderFilterRequest.setAction(bussinessTypeEntity.getAction());
        OrderEntity orderEntity = orderService.findOne(orderFilterRequest);
        if (orderEntity != null) {
            return ResultVOUtils.error(500, "已存在该类型扫码单据，无法删除！");
        }
//        if (bussinessTypeEntity.getLocalAction() != null && !bussinessTypeEntity.getLocalAction().equals("")) {
//            BussinessLocalTypeEntity bussinessLocalTypeEntity = bussinessLocalTypeService.findBTByAction(bussinessTypeEntity.getLocalAction());
//            if (bussinessLocalTypeEntity != null && !"".equals(bussinessLocalTypeEntity)) {
//                return ResultVOUtils.error(500, "该扫码单据类型已绑定业务单据类型，无法删除！");
//            }
//        }

        bussinessTypeService.deleteById(id);
        return ResultVOUtils.success("删除成功");
    }

    @AuthRuleAnnotation("")
    @PostMapping("/udiwms/bussinessType/update")
    public BaseResponse updateBussinessType(@RequestBody BussinessTypeEntity bussinessTypeEntity,
                                            BindingResult bindingResult) {

        if (bindingResult.hasErrors()) {
            return ResultVOUtils.error(ResultEnum.PARAM_VERIFY_FALL, bindingResult.getFieldError().getDefaultMessage());
        }
        if (bussinessTypeEntity != null) {
            bussinessTypeService.updateBussinessType(bussinessTypeEntity);
        } else {
            ResultVOUtils.error(999, "参数错误");
        }
        return ResultVOUtils.success("更新成功");
    }

    @AuthRuleAnnotation("")
    @PostMapping("/udiwms/bussinessType/insert")
    public BaseResponse insertBussinessType(@RequestBody BussinessTypeEntity bussinessTypeEntity, BindingResult bindingResult) {

        if (bindingResult.hasErrors()) {
            return ResultVOUtils.error(ResultEnum.PARAM_VERIFY_FALL, bindingResult.getFieldError().getDefaultMessage());
        }

        if (bussinessTypeEntity != null) {
            bussinessTypeEntity.setAction("SC" + CustomUtil.getId());
            bussinessTypeService.insertBussinessType(bussinessTypeEntity);
        } else {
            ResultVOUtils.error(999, "参数错误");
        }
        return ResultVOUtils.success("添加成功");
    }

    public String getCustomerId() {
        ServletRequestAttributes attributes = (ServletRequestAttributes) RequestContextHolder.getRequestAttributes();
        if (attributes == null) {
            throw new JsonException(ResultEnum.NOT_NETWORK);
        }
        HttpServletRequest request = attributes.getRequest();
        String userId = request.getHeader("ADMIN_ID");
        AuthAdmin authAdmin = authAdminService.findById(Long.parseLong(userId));
        return authAdmin.getCustomerId() + "";
    }

    //扫码单据类型导入
    @AuthRuleAnnotation("")
    @PostMapping("/udiwms/busstiness/file/upload")
    public BaseResponse uploadProducts(@RequestParam("file") List<MultipartFile> files) {
        for (int i = 0; i < files.size(); i++) {
            MultipartFile file = files.get(i);
            if (file.isEmpty()) {
                return ResultVOUtils.error(500, "上传第" + (i++) + "个文件失败");
            }
            try {
                InputStream inputStream = file.getInputStream();
                String json = FileUtils.readStream(inputStream);
                List<BussinessTypeEntity> bussinessTypeEntities = JSON.parseArray(json, BussinessTypeEntity.class);
                if (bussinessTypeEntities != null && bussinessTypeEntities.size() > 0) {
                    for (BussinessTypeEntity bussinessTypeEntity : bussinessTypeEntities) {
                        bussinessTypeService.insertIgnoreBussinessType(bussinessTypeEntity);
                    }
                }
            } catch (Exception e) {
                e.printStackTrace();
                return ResultVOUtils.error(500, "文件格式错误！");
            }
        }

        return ResultVOUtils.success("导入成功！");

    }

    /**
     * 获取候选补单单据类型
     *
     * @return
     */
    @AuthRuleAnnotation("")
    @GetMapping("/warehouse/bussinessType/candidateBussinessType")
    public BaseResponse candidateBussinessType(CndidateRequest cndidateRequest) {
        if (StrUtil.isBlank(cndidateRequest.getMainAction())) {
            return ResultVOUtils.error(ResultEnum.DATA_ERROR);
        }
        List<BussinessTypeEntity> bussinessTypeEntities = bussinessTypeService.candidateBussinessType(cndidateRequest.getMainAction());
        if (!StrUtil.isEmpty(cndidateRequest.getCurAction())) {
            BussinessTypeEntity bussinessTypeEntity = bussinessTypeService.findBTByAction(cndidateRequest.getCurAction());
            bussinessTypeEntities.add(bussinessTypeEntity);
        }
        //查询补单单据类型
        return ResultVOUtils.success(bussinessTypeEntities);
    }

}
