package com.glxp.udi.admin.controller.info;

import com.alibaba.fastjson.JSONObject;
import com.alibaba.fastjson.TypeReference;
import com.github.pagehelper.PageInfo;
import com.glxp.udi.admin.annotation.AuthRuleAnnotation;
import com.glxp.udi.admin.entity.info.PlatformEntity;
import com.glxp.udi.admin.entity.inout.UdiInfoEntity;
import com.glxp.udi.admin.entity.inout.UnitMaintainEntity;
import com.glxp.udi.admin.exception.JsonException;
import com.glxp.udi.admin.req.inout.UnitMaintainFilterRequest;
import com.glxp.udi.admin.res.PageSimpleResponse;
import com.glxp.udi.admin.res.basic.SpmsBusTypeResponse;
import com.glxp.udi.admin.service.info.PlatformService;
import com.glxp.udi.admin.service.inout.UnitMaintainService;
import com.glxp.udi.admin.util.UuidUtils;
import com.glxp.udi.common.enums.ResultEnum;
import com.glxp.udi.common.res.BaseResponse;
import com.glxp.udi.common.util.ResultVOUtils;

import org.springframework.http.converter.StringHttpMessageConverter;
import org.springframework.util.MultiValueMap;
import org.springframework.util.LinkedMultiValueMap;
import org.springframework.validation.BindingResult;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.client.RestTemplate;
import org.springframework.http.MediaType;
import org.springframework.http.HttpEntity;
import org.springframework.http.HttpHeaders;
import org.springframework.http.HttpMethod;
import org.springframework.http.ResponseEntity;
import org.springframework.web.context.request.RequestContextHolder;
import org.springframework.web.context.request.ServletRequestAttributes;
import org.springframework.web.client.RestTemplate;
import lombok.extern.slf4j.Slf4j;

import com.alibaba.fastjson.JSON;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.validation.Valid;
import java.util.List;
import java.util.Map;
import java.io.IOException;
import java.nio.charset.Charset;
import java.util.HashMap;

import com.glxp.udi.admin.util.HttpClient;

@RestController
@Slf4j
public class PlatformController {

    @Resource
    private PlatformService platformService;
    @Resource
    private UnitMaintainService unitMaintainService;

    @AuthRuleAnnotation("")
    @PostMapping("/udims/platform/remove")
    public BaseResponse remove(@RequestBody PlatformEntity platformEntity) {
        if (platformService.remove(platformEntity.getId()) > 0)
            ResultVOUtils.success("删除成功");
        return ResultVOUtils.error(500, "删除失败");
    }


    @AuthRuleAnnotation("")
    @PostMapping("/udims/platform/update")
    public BaseResponse update(@RequestBody PlatformEntity platformEntity) {
        if (platformService.update(platformEntity) > 0)
            ResultVOUtils.success("修改成功");

        return ResultVOUtils.success("修改失败");
    }

    @AuthRuleAnnotation("")
    @GetMapping("/udims/platform/list")
    public BaseResponse list(@RequestParam Map<String, Object> params) {
        List<PlatformEntity> list = platformService.list(params);
        if (params.get("page") != null && params.get("limit") != null) {
            params.put("offset", (Integer.valueOf(params.get("page").toString()) - 1) * (Integer.valueOf(params.get("limit").toString())));
        }
        int total = platformService.count(params);
        PageSimpleResponse<PlatformEntity> pageSimpleResponse = new PageSimpleResponse<>();
        pageSimpleResponse.setTotal(Long.valueOf(String.valueOf(total)));
        pageSimpleResponse.setList(list);

        return ResultVOUtils.success(pageSimpleResponse);
    }

    @AuthRuleAnnotation("")
    @PostMapping("/udims/platform/link")
    public BaseResponse update(@RequestBody UnitMaintainEntity unitMaintainEntity) {
        PlatformEntity platformEntity = platformService.get(unitMaintainEntity.getPlatformId());
        if (platformEntity != null) {
            String url = platformEntity.getHost() + "/verify";

            Map<String, Object> map = new HashMap<String, Object>();
            map.put("username", unitMaintainEntity.getPlatformUsername());
            map.put("password", unitMaintainEntity.getPlatformPassword());

            HttpHeaders headers = new HttpHeaders();
            headers.setContentType(MediaType.APPLICATION_JSON_UTF8);

            HttpEntity<String> request = new HttpEntity<String>(JSON.toJSONString(map), headers);
            RestTemplate restTemplate = new RestTemplate();
            log.error(url);

            String result = restTemplate.postForObject(url, request, String.class, map);
            log.error(result);
            Map<String, Object> object = JSON.parseObject(result, Map.class);

            if (object != null && object.get("data") != null) {
                Map<String, Object> data = JSON.parseObject(JSON.toJSONString(object.get("data")), Map.class);
                log.error(JSON.toJSONString(object.get("data")));
                if (data.get("appid") != null) {
                    unitMaintainEntity.setAppid(data.get("appid").toString());
                    if (data.get("apiKey") != null)
                        unitMaintainEntity.setApiKey(data.get("apiKey").toString());
                    if (data.get("secretKey") != null)
                        unitMaintainEntity.setSecretKey(data.get("secretKey").toString());
                } else {
                    return ResultVOUtils.error(500, "关联验证失败,请联系管理人员");
                }
            } else if (object != null && object.get("message") != null) {
                return ResultVOUtils.error(500, object.get("message").toString());
            } else {
                return ResultVOUtils.error(500, "关联失败,请联系管理人员");
            }

        } else {
            return ResultVOUtils.error(500, "未查询到平台信息");
        }
        unitMaintainService.updateUnit(unitMaintainEntity);
        return ResultVOUtils.success("关联成功");
    }


    @AuthRuleAnnotation("")
    @GetMapping("/udims/platform/getPlatformBusTypes")
    public BaseResponse getPlatformBusTypes(UnitMaintainFilterRequest unitMaintainFilterRequest) {

        UnitMaintainEntity unitMaintainEntity = unitMaintainService.selectByUnitId(unitMaintainFilterRequest.getUnitId());
        if (unitMaintainEntity.getSecretKey() == null) {
            return ResultVOUtils.error(500, "未验证，请先关联验证！");
        }
        PlatformEntity platformEntity = platformService.get(unitMaintainEntity.getPlatformId());
        if (platformEntity != null) {
            HttpHeaders headers = new HttpHeaders();
            headers.add("api_key", unitMaintainEntity.getApiKey());
            headers.add("secret_key", unitMaintainEntity.getSecretKey());
            String response = HttpClient.mipsGetHead(platformEntity.getHost() + "/udiwms/bussinessType/udimsFilter", null, headers);
            BaseResponse<PageSimpleResponse<SpmsBusTypeResponse>> baseResponse =
                    JSONObject.parseObject(response, new TypeReference<BaseResponse<PageSimpleResponse<SpmsBusTypeResponse>>>() {
                    });
            if (baseResponse.getCode() == 20000) {
                return baseResponse;
            }
        }
        return ResultVOUtils.error(500, "连接自助平台服务器失败！");
    }


}
