package com.glxp.udi.admin.controller.inout;

import com.github.pagehelper.PageInfo;
import com.glxp.udi.admin.entity.inout.BussinessContrastTypeEntity;
import com.glxp.udi.admin.entity.inout.BussinessTypeEntity;
import com.glxp.udi.admin.req.inout.DeleteRequest;
import com.glxp.udi.admin.req.receipt.BussinessTypeConstrastFilterRequest;
import com.glxp.udi.admin.req.receipt.BussinessTypeFilterRequest;
import com.glxp.udi.admin.res.PageSimpleResponse;
import com.glxp.udi.admin.res.basic.BussinessTypResponse;
import com.glxp.udi.admin.service.inout.BussinessTypeContrastService;
import com.glxp.udi.common.enums.ResultEnum;
import com.glxp.udi.common.res.BaseResponse;
import com.glxp.udi.common.util.ResultVOUtils;
import org.springframework.validation.BindingResult;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.util.List;

@RestController
public class BussinessTypeContrastController {


    @Resource
    private BussinessTypeContrastService bussinessTypeService;


    @GetMapping("/udiwms/btcontrast/filter")
    public BaseResponse filterJoinBussinessType(BussinessTypeConstrastFilterRequest bussinessTypeFilterRequest,
                                                BindingResult bindingResult) {

        if (bindingResult.hasErrors()) {
            return ResultVOUtils.error(ResultEnum.PARAM_VERIFY_FALL, bindingResult.getFieldError().getDefaultMessage());
        }
        List<BussinessContrastTypeEntity> bussinessTypeEntities;
        bussinessTypeEntities = bussinessTypeService.filterList(bussinessTypeFilterRequest);
        PageInfo<BussinessContrastTypeEntity> pageInfo;
        pageInfo = new PageInfo<>(bussinessTypeEntities);
        PageSimpleResponse<BussinessContrastTypeEntity> pageSimpleResponse = new PageSimpleResponse<>();
        pageSimpleResponse.setTotal(pageInfo.getTotal());
        pageSimpleResponse.setList(bussinessTypeEntities);
        return ResultVOUtils.success(pageSimpleResponse);
    }


    @PostMapping("/udiwms/btcontrast/delete")
    public BaseResponse deleteBussinessType(@RequestBody DeleteRequest deleteRequest, BindingResult bindingResult) {

        if (bindingResult.hasErrors()) {
            return ResultVOUtils.error(ResultEnum.PARAM_VERIFY_FALL, bindingResult.getFieldError().getDefaultMessage());
        }
        String id = deleteRequest.getId();
        bussinessTypeService.deleteById(id);
        return ResultVOUtils.success("删除成功");
    }

    @PostMapping("/udiwms/btcontrast/update")
    public BaseResponse updateBussinessType(@RequestBody BussinessContrastTypeEntity bussinessTypeEntity,
                                            BindingResult bindingResult) {

        if (bindingResult.hasErrors()) {
            return ResultVOUtils.error(ResultEnum.PARAM_VERIFY_FALL, bindingResult.getFieldError().getDefaultMessage());
        }
        if (bussinessTypeEntity != null) {
            bussinessTypeService.updateBussinessType(bussinessTypeEntity);
        } else {
            ResultVOUtils.error(999, "参数错误");
        }
        return ResultVOUtils.success("更新成功");
    }


    @PostMapping("/udiwms/btcontrast/insert")
    public BaseResponse insertBussinessType(@RequestBody BussinessContrastTypeEntity bussinessTypeEntity, BindingResult bindingResult) {

        if (bindingResult.hasErrors()) {
            return ResultVOUtils.error(ResultEnum.PARAM_VERIFY_FALL, bindingResult.getFieldError().getDefaultMessage());
        }
        if (bussinessTypeEntity != null) {
            bussinessTypeService.insertBussinessType(bussinessTypeEntity);
        } else {
            ResultVOUtils.error(999, "参数错误");
        }
        return ResultVOUtils.success("添加成功");
    }

}
