package com.glxp.udi.admin.controller.param;

import com.github.pagehelper.PageInfo;
import com.glxp.udi.admin.annotation.AuthRuleAnnotation;
import com.glxp.udi.admin.dao.info.ScheduledDao;
import com.glxp.udi.admin.entity.info.ScheduledEntity;
import com.glxp.udi.admin.entity.param.SystemParamConfigEntity;
import com.glxp.udi.admin.req.param.SystemParamConfigRequest;
import com.glxp.udi.admin.req.param.SystemParamConfigSaveRequest;
import com.glxp.udi.admin.res.PageSimpleResponse;
import com.glxp.udi.admin.res.param.SystemParamConfigResponse;
import com.glxp.udi.admin.service.param.SystemParamConfigService;
import com.glxp.udi.admin.util.CronUtils;
import com.glxp.udi.common.enums.ResultEnum;
import com.glxp.udi.common.res.BaseResponse;
import com.glxp.udi.common.util.ResultVOUtils;
import org.springframework.beans.BeanUtils;
import org.springframework.validation.BindingResult;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import javax.validation.Valid;
import java.util.List;
import java.util.stream.Collectors;

@RestController
public class SystemParamConfigController {

    @Resource
    private SystemParamConfigService systemParamConfigService;
    @Resource
    ScheduledDao scheduledDao;


    @AuthRuleAnnotation("system/param/config/list")
    @GetMapping("/system/param/config/list")
    public BaseResponse list(@Valid SystemParamConfigRequest systemParamConfigRequest,
                             BindingResult bindingResult) {

        if (bindingResult.hasErrors()) {
            return ResultVOUtils.error(ResultEnum.PARAM_VERIFY_FALL, bindingResult.getFieldError().getDefaultMessage());
        }

        systemParamConfigRequest.setParamStatus(1);
        List<SystemParamConfigEntity> systemParamConfigEntityList = systemParamConfigService.queryPage(systemParamConfigRequest);
        List<SystemParamConfigResponse> systemParamConfigResponseList = systemParamConfigEntityList.stream().map(item -> {
            SystemParamConfigResponse systemParamConfigResponse = new SystemParamConfigResponse();
            BeanUtils.copyProperties(item, systemParamConfigResponse);
            return systemParamConfigResponse;
        }).collect(Collectors.toList());

        PageInfo<SystemParamConfigEntity> pageInfo = new PageInfo<>(systemParamConfigEntityList);
        PageSimpleResponse<SystemParamConfigResponse> pageSimpleResponse = new PageSimpleResponse<>();
        pageSimpleResponse.setTotal(pageInfo.getTotal());
        pageSimpleResponse.setList(systemParamConfigResponseList);
        return ResultVOUtils.success(pageSimpleResponse);
    }

    @AuthRuleAnnotation("system/param/config/save")
    @PostMapping("/system/param/config/save")
    public BaseResponse save(@RequestBody @Valid SystemParamConfigSaveRequest systemParamConfigSaveRequest,
                             BindingResult bindingResult) {

        if (bindingResult.hasErrors()) {
            return ResultVOUtils.error(ResultEnum.PARAM_VERIFY_FALL, bindingResult.getFieldError().getDefaultMessage());
        }

        SystemParamConfigEntity systemParamConfigEntity = new SystemParamConfigEntity();
        BeanUtils.copyProperties(systemParamConfigSaveRequest, systemParamConfigEntity);

        boolean b = systemParamConfigService.insert(systemParamConfigEntity);
        if (!b) {
            return ResultVOUtils.error(ResultEnum.NOT_NETWORK);
        }

        return ResultVOUtils.success();
    }

    @AuthRuleAnnotation("system/param/config/update")
    @PostMapping("/system/param/config/update")
    public BaseResponse update(@RequestBody SystemParamConfigSaveRequest systemParamConfigSaveRequest) {
//        systemParamConfigSaveRequest.setId(1);
        systemParamConfigService.updateById(systemParamConfigSaveRequest);
        if (systemParamConfigSaveRequest.getParentId() == 0) {
            SystemParamConfigSaveRequest systemParamConfigSaveRequest1 = new SystemParamConfigSaveRequest();
            systemParamConfigSaveRequest1.setParentId(systemParamConfigSaveRequest.getId());
            if (systemParamConfigSaveRequest.getParamValue().equals("1")) {
                systemParamConfigSaveRequest1.setParamStatus(1);
            } else {
                systemParamConfigSaveRequest1.setParamStatus(0);
            }
            systemParamConfigService.updateParentId(systemParamConfigSaveRequest1);
        }


        //出入库新增单据校验
        if (systemParamConfigSaveRequest.getParamKey().equals("io_transInout_interval")) {
            try {
                int time = 5;
                if (!"0".equals(systemParamConfigSaveRequest.getParamValue())) {
                    time = Integer.parseInt(systemParamConfigSaveRequest.getParamValue());
                }
                String cronStr = CronUtils.parseMinuteIntervel(time);
                ScheduledEntity scheduledEntity = new ScheduledEntity();
                scheduledEntity.setCron(cronStr);
                scheduledEntity.setCronName("transInout");
                scheduledDao.modifyScheduled(scheduledEntity);
            } catch (Exception e) {
                return ResultVOUtils.error(500, "格式错误！");
            }
        } else if (systemParamConfigSaveRequest.getParamKey().equals("io_erpcheck_interval")) {
            try {
                int time = 5;
                if (!"0".equals(systemParamConfigSaveRequest.getParamValue())) {
                    time = Integer.parseInt(systemParamConfigSaveRequest.getParamValue());
                }
                String cronStr = CronUtils.parseMinuteIntervel(time);
                ScheduledEntity scheduledEntity = new ScheduledEntity();
                scheduledEntity.setCron(cronStr);
                scheduledEntity.setCronName("erpCheck");
                scheduledDao.modifyScheduled(scheduledEntity);
            } catch (Exception e) {
                return ResultVOUtils.error(500, "格式错误！");
            }
        } else if (systemParamConfigSaveRequest.getParamKey().equals("supplement_order_interval")) {
            try {
                int time = 5;
                if (!"0".equals(systemParamConfigSaveRequest.getParamValue())) {
                    time = Integer.parseInt(systemParamConfigSaveRequest.getParamValue());
                }
                String cornStr = CronUtils.parseMinuteIntervel(time);
                ScheduledEntity scheduledEntity = new ScheduledEntity();
                scheduledEntity.setCron(cornStr);
                scheduledEntity.setCronName("supplementOrderTask");
                scheduledDao.modifyScheduled(scheduledEntity);
            } catch (Exception e) {
                return ResultVOUtils.error(500, "格式错误！");
            }
        }
        return ResultVOUtils.success("修改成功");
    }


    //key搜索
    @AuthRuleAnnotation("")
    @GetMapping("/udiwms/sys/config/selectByKey")
    public BaseResponse selectByKey(SystemParamConfigRequest systemParamConfigRequest,
                                    BindingResult bindingResult) {

        if (bindingResult.hasErrors()) {
            return ResultVOUtils.error(ResultEnum.PARAM_VERIFY_FALL, bindingResult.getFieldError().getDefaultMessage());
        }
        SystemParamConfigEntity systemParamConfigEntity = systemParamConfigService.selectByParamKey(systemParamConfigRequest.getParamKey());
        return ResultVOUtils.success(systemParamConfigEntity);
    }
}
