package com.glxp.udi.admin.httpclient;

import com.alibaba.fastjson.JSONObject;
import com.alibaba.fastjson.TypeReference;
import com.glxp.udi.admin.entity.basic.BasicThirdSysEntity;
import com.glxp.udi.admin.req.basic.BasicUnitMaintainFilterRequest;
import com.glxp.udi.admin.req.basic.FilterErpGoodsRequest;
import com.glxp.udi.admin.res.PageSimpleResponse;
import com.glxp.udi.admin.res.basic.ErpProductsResponse;
import com.glxp.udi.admin.res.basic.ErpUnitsResponse;
import com.glxp.udi.admin.service.basic.BasicThirdSysService;
import com.glxp.udi.admin.util.HttpClient;
import com.glxp.udi.common.res.BaseResponse;
import com.glxp.udi.common.util.ResultVOUtils;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.HashMap;
import java.util.Map;

/**
 * 获取ERP基础数据
 */
@Slf4j
@Service
public class ErpBasicClient {

    @Autowired
    private BasicThirdSysService basicThirdSysService;

    //获取往来单位
    public BaseResponse<PageSimpleResponse<ErpUnitsResponse>> getErpCrop(BasicUnitMaintainFilterRequest unitMaintainFilterRequest, String url) {
        Map<String, Object> paramMap = new HashMap<>(16);
        paramMap.put("name", unitMaintainFilterRequest.getName());
        paramMap.put("unitId", unitMaintainFilterRequest.getUnitId());
        paramMap.put("key", unitMaintainFilterRequest.getKey());
        paramMap.put("page", unitMaintainFilterRequest.getPage());
        paramMap.put("limit", unitMaintainFilterRequest.getLimit());

        //查询第三方系统接口授权参数
        BasicThirdSysEntity basicThirdSysEntity = basicThirdSysService.selectByThirdId(unitMaintainFilterRequest.getThirdSys());
        String response = HttpClient.uCloudPost(url, unitMaintainFilterRequest, basicThirdSysEntity);
        try {
            BaseResponse<PageSimpleResponse<ErpUnitsResponse>> udiDlDeviceResponse =
                    JSONObject.parseObject(response, new TypeReference<BaseResponse<PageSimpleResponse<ErpUnitsResponse>>>() {
                    });
            return udiDlDeviceResponse;
        } catch (Exception e) {
            log.error("获取往来单位异常", e);
            return ResultVOUtils.error(500, "连接ERP服务出错！");
        }
    }

    //获取产品信息
    public BaseResponse<PageSimpleResponse<ErpProductsResponse>> getErpProducts(FilterErpGoodsRequest filterErpGoodsRequest, String url) {
        Map<String, Object> paramMap = new HashMap<>(16);
        paramMap.put("code", filterErpGoodsRequest.getCode());
        paramMap.put("name", filterErpGoodsRequest.getName());
        paramMap.put("limit", filterErpGoodsRequest.getLimit());
        paramMap.put("page", filterErpGoodsRequest.getPage());

        //查询第三方系统接口授权参数
        BasicThirdSysEntity basicThirdSysEntity = basicThirdSysService.selectByThirdId(filterErpGoodsRequest.getThirdSys());
        String response = HttpClient.uCloudPost(url, filterErpGoodsRequest, basicThirdSysEntity);
        try {
            BaseResponse<PageSimpleResponse<ErpProductsResponse>> udiDlDeviceResponse =
                    JSONObject.parseObject(response, new TypeReference<BaseResponse<PageSimpleResponse<ErpProductsResponse>>>() {
                    });
            return udiDlDeviceResponse;
        } catch (Exception e) {
            log.error("获取产品信息异常", e);
            return ResultVOUtils.error(500, "连接ERP服务出错！");
        }
    }


}
