package com.glxp.udi.admin.service.auth.impl;

import com.github.pagehelper.PageHelper;
import com.glxp.udi.admin.dao.auth.AuthRoleDao;
import com.glxp.udi.admin.dao.basic.BasicBussinessTypeRoleDao;
import com.glxp.udi.admin.entity.auth.AuthRole;
import com.glxp.udi.admin.entity.basic.BasicBussinessTypeRoleEntity;
import com.glxp.udi.admin.req.auth.AuthRoleQueryRequest;
import com.glxp.udi.admin.service.auth.AuthRoleService;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

@Service
public class AuthRoleServiceImpl implements AuthRoleService {

    @Resource
    private AuthRoleDao authRoleDao;
    @Resource
    private BasicBussinessTypeRoleDao basicBussinessTypeRoleDao;

    /**
     * 查询列表
     *
     * @return
     */
    @Override
    public List<AuthRole> listAdminPage(AuthRoleQueryRequest authRoleQueryRequest) {
        int offset = (authRoleQueryRequest.getPage() - 1) * authRoleQueryRequest.getLimit();
        PageHelper.offsetPage(offset, authRoleQueryRequest.getLimit());
        List<AuthRole> list = authRoleDao.listAdminPage(authRoleQueryRequest);
        return list;
    }

    /**
     * 查询管理员页面的列表
     *
     * @param page
     * @param limit
     * @param status
     * @return
     */
    @Override
    public List<AuthRole> listAuthAdminRolePage(Integer page, Integer limit, Integer status) {
        page = page != null && page > 0 ? page : 1;
        limit = limit != null && limit > 0 && limit < 100 ? limit : 100;
        int offset = (page - 1) * limit;
        PageHelper.offsetPage(offset, limit);
        List<AuthRole> list = authRoleDao.listAuthAdminRolePage(status);
        return list;
    }

    /**
     * 根据名称查询
     *
     * @param name
     * @return
     */
    @Override
    public AuthRole findByName(String name) {
        return authRoleDao.findByName(name);
    }

    /**
     * 插入
     *
     * @param authRole
     * @return
     */
    @Override
    public boolean insertAuthRole(AuthRole authRole) {

        authRole.setCreateTime(new Date());
        authRole.setUpdateTime(new Date());

        return authRoleDao.insertAuthRole(authRole);
    }

    /**
     * 修改
     *
     * @param authRole
     * @return
     */
    @Override
    public boolean updateAuthRole(AuthRole authRole) {
        authRole.setUpdateTime(new Date());
        return authRoleDao.updateAuthRole(authRole);
    }

    @Override
    public List<AuthRole> listCustomerRoles(Integer page, Integer limit, Integer isCustomer) {
        page = page != null && page > 0 ? page : 1;
        limit = limit != null && limit > 0 && limit < 100 ? limit : 100;
        int offset = (page - 1) * limit;
        PageHelper.offsetPage(offset, limit);
        List<AuthRole> list = authRoleDao.listCustomerRoles(isCustomer);
        return list;
    }

    @Override
    public List<AuthRole> listAuthRoles2(Integer page, Integer limit) {
        page = page != null && page > 0 ? page : 1;
        limit = limit != null && limit > 0 && limit < 100 ? limit : 100;
        int offset = (page - 1) * limit;
        PageHelper.offsetPage(offset, limit);
        List<AuthRole> list = authRoleDao.listAuthRoles2();
        return list;
    }

    /**
     * 删除
     *
     * @param id
     * @return
     */
    @Override
    public boolean deleteById(Long id) {
        return authRoleDao.deleteById(id);
    }

    @Override
    public List<BasicBussinessTypeRoleEntity> getBussinessTypeRole(Long roleId) {
        return basicBussinessTypeRoleDao.getListByRoleId(roleId);
    }

    @Override
    public void updateBussinessTypeRole(Long roleId, List<String> actions) {
        //删除之前的扫码单据类型授权数据
        basicBussinessTypeRoleDao.deleteByRoleId(roleId);
        //添加新的扫码单据数据类型
        List<BasicBussinessTypeRoleEntity> data = new ArrayList<>(actions.size());
        actions.forEach(action -> {
            BasicBussinessTypeRoleEntity entity = new BasicBussinessTypeRoleEntity();
            entity.setRole_id(roleId);
            entity.setAction(action);
            data.add(entity);
        });
        basicBussinessTypeRoleDao.insert(data);
    }
}
