package com.glxp.udi.admin.service.basic.impl;

import cn.hutool.core.util.StrUtil;
import com.github.pagehelper.PageHelper;
import com.glxp.udi.admin.dao.auth.AuthLicenseDao;
import com.glxp.udi.admin.dao.basic.BasicThirdSysDao;
import com.glxp.udi.admin.entity.auth.AuthLicense;
import com.glxp.udi.admin.entity.basic.BasicThirdSysEntity;
import com.glxp.udi.admin.req.basic.FilterBasicThirdSysRequest;
import com.glxp.udi.admin.service.basic.BasicThirdSysService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.Collections;
import java.util.List;

@Slf4j
@Service
public class BasicThirdSysServiceImpl implements BasicThirdSysService {

    @Resource
    BasicThirdSysDao basicThirdSysDao;
    @Resource
    private AuthLicenseDao authLicenseDao;

    @Override
    public boolean insert(BasicThirdSysEntity basicThirdSysEntity) {
        return basicThirdSysDao.insert(basicThirdSysEntity);
    }

    @Override
    public boolean updateBasicThiSys(BasicThirdSysEntity basicThirdSysEntity) {
        try {
            //同步更新本系统的授权码和秘钥
            if (StrUtil.isNotBlank(basicThirdSysEntity.getLicenseApikey()) || StrUtil.isNotBlank(basicThirdSysEntity.getLicenseSecretkey())) {
                authLicenseDao.updateLicenseByName(basicThirdSysEntity.getLicenseApikey(), basicThirdSysEntity.getLicenseSecretkey(), "UDI自助管理平台");
            }
            basicThirdSysDao.updateBasicThiSys(basicThirdSysEntity);
        } catch (Exception e) {
            log.error("更新第三方系统信息异常", e);
        }
        return true;
    }

    @Override
    public BasicThirdSysEntity selectByThirdId(String thirdId) {
        return basicThirdSysDao.selectByThirdId(thirdId);
    }

    @Override
    public List<BasicThirdSysEntity> filterBasicThiSys(FilterBasicThirdSysRequest filterBasicThirdSysRequest) {
        if (filterBasicThirdSysRequest == null) {
            return Collections.emptyList();
        }

        if (filterBasicThirdSysRequest.getPage() != null) {
            int offset = (filterBasicThirdSysRequest.getPage() - 1) * filterBasicThirdSysRequest.getLimit();
            PageHelper.offsetPage(offset, filterBasicThirdSysRequest.getLimit());
        }
        List<BasicThirdSysEntity> data = basicThirdSysDao.filterBasicThiSys(filterBasicThirdSysRequest);
        //查询本系统的授权码
        AuthLicense license = authLicenseDao.selectLicenseByName("UDI自助管理平台");
        if (null != license) {
            data.forEach(basicThirdSysEntity -> {
                basicThirdSysEntity.setLicenseApikey(license.getApiKey());
                basicThirdSysEntity.setLicenseSecretkey(license.getSecretKey());
            });
        }
        return data;
    }

    @Override
    public BasicThirdSysEntity selectMainThrSys() {
        FilterBasicThirdSysRequest filterBasicThirdSysRequest = new FilterBasicThirdSysRequest();
        filterBasicThirdSysRequest.setMainSys(true);
        List<BasicThirdSysEntity> data = basicThirdSysDao.filterBasicThiSys(filterBasicThirdSysRequest);
        if (data != null && data.size() > 0) {
            return data.get(0);
        }
        return null;
    }
}
