package com.glxp.udi.admin.service.inout.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.util.StrUtil;
import com.github.pagehelper.PageHelper;
import com.glxp.udi.admin.constant.ConstantStatus;
import com.glxp.udi.admin.dao.basic.BussinessTypeDao;
import com.glxp.udi.admin.dao.inout.*;
import com.glxp.udi.admin.dao.inventory.InvWarehouseDao;
import com.glxp.udi.admin.entity.basic.BussinessTypeEntity;
import com.glxp.udi.admin.entity.inout.OrderEntity;
import com.glxp.udi.admin.entity.inout.StockOrderEntity;
import com.glxp.udi.admin.entity.inout.WarehouseEntity;
import com.glxp.udi.admin.entity.param.SystemParamConfigEntity;
import com.glxp.udi.admin.req.inout.OrderFilterRequest;
import com.glxp.udi.admin.req.inout.OrderQueryRequest;
import com.glxp.udi.admin.res.inout.StockOrderResponse;
import com.glxp.udi.admin.service.inout.OrderService;
import com.glxp.udi.admin.service.param.SystemParamConfigService;
import com.glxp.udi.admin.util.CustomUtil;
import com.glxp.udi.common.enums.ResultEnum;
import com.glxp.udi.common.res.BaseResponse;
import com.glxp.udi.common.util.ResultVOUtils;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

@Slf4j
@Service
public class OrderServiceImpl implements OrderService {

    @Resource
    OrderDao orderDao;
    @Resource
    WarehouseDao warehouseDao;
    @Resource
    BussinessTypeDao bussinessTypeDao;
    @Resource
    StockOrderDao stockOrderDao;
    @Resource
    InvWarehouseDao invWarehouseDao;
    @Resource
    CodesDao codesDao;
    @Resource
    CodesTempDao codesTempDao;
    @Resource
    SystemParamConfigService systemParamConfigService;

    @Override
    public List<OrderEntity> listOrders(OrderQueryRequest orderQueryRequest) {
        if (orderQueryRequest == null) {
            return Collections.emptyList();
        }
        int offset = (orderQueryRequest.getPage() - 1) * orderQueryRequest.getLimit();
        PageHelper.offsetPage(offset, orderQueryRequest.getLimit());
        return orderDao.listOrder(orderQueryRequest);
    }


    @Override
    public boolean insertOrder(OrderEntity orderEntity) {
        return orderDao.insertOrder(orderEntity);
    }

    @Override
    public boolean updateOrder(OrderEntity orderEntity) {
        return orderDao.updateOrder(orderEntity);
    }

    @Override
    public List<OrderEntity> listOrderError(OrderQueryRequest orderQueryRequest) {
        if (orderQueryRequest == null) {
            return Collections.emptyList();
        }
        int offset = (orderQueryRequest.getPage() - 1) * orderQueryRequest.getLimit();
        PageHelper.offsetPage(offset, orderQueryRequest.getLimit());
        return orderDao.listOrderError(orderQueryRequest);
    }

    @Override
    public List<OrderEntity> listOrderRepeat(OrderQueryRequest orderQueryRequest) {
        if (orderQueryRequest == null) {
            return Collections.emptyList();
        }
        int offset = (orderQueryRequest.getPage() - 1) * orderQueryRequest.getLimit();
        PageHelper.offsetPage(offset, orderQueryRequest.getLimit());
        return orderDao.listOrderRepeat(orderQueryRequest);
    }

    @Override
    public boolean deleteByOrderId(String orderId) {
        return orderDao.deleteByOrderId(orderId);
    }

    @Override
    public boolean deleteById(String id) {
        return orderDao.deleteById(id);
    }

    @Override
    public boolean updateUnit(OrderEntity orderEntity) {
        return orderDao.updateUnit(orderEntity);
    }

    @Override
    public boolean updateOrderStatus(String orderId, Integer status) {
        return orderDao.updateOrderStatus(orderId, status);
    }

    @Override
    public boolean updateExportStatus(String orderId, Integer exportStatus) {
        return orderDao.updateExportStatus(orderId, exportStatus);
    }

    @Override
    public boolean updateSignStatus(String orderId, String signStatus) {
        return orderDao.updateSignStatus(orderId, signStatus);
    }

    @Override
    public boolean updateContrastStatus(String orderId, String contrastStatus) {
        return orderDao.updateContrastStatus(orderId, contrastStatus);
    }

    @Override
    public boolean updateRemark(String orderId, String remark) {
        return orderDao.updateRemark(orderId, remark);
    }

    @Override
    public List<OrderEntity> findAllOrders(OrderFilterRequest orderFilterRequest) {
        return orderDao.filterList(orderFilterRequest);
    }

    @Override
    public List<OrderEntity> filterListOr(OrderFilterRequest orderFilterRequest) {
        if (orderFilterRequest == null) {
            return Collections.emptyList();
        }
        int offset = (orderFilterRequest.getPage() - 1) * orderFilterRequest.getLimit();
        PageHelper.offsetPage(offset, orderFilterRequest.getLimit());
        return orderDao.filterListOr(orderFilterRequest);
    }

    @Override
    public List<OrderEntity> filterList(OrderFilterRequest orderFilterRequest) {
        if (orderFilterRequest == null) {
            return Collections.emptyList();
        }
        int offset = (orderFilterRequest.getPage() - 1) * orderFilterRequest.getLimit();
        PageHelper.offsetPage(offset, orderFilterRequest.getLimit());
        return orderDao.filterList(orderFilterRequest);
    }

    @Override
    public OrderEntity findOne(OrderFilterRequest orderFilterRequest) {
        return orderDao.findOne(orderFilterRequest);
    }

    @Override
    public OrderEntity findById(String orderId) {
        OrderFilterRequest orderFilterRequest = new OrderFilterRequest();
        orderFilterRequest.setId(orderId);
        return orderDao.findOne(orderFilterRequest);
    }

    @Override
    public List<String> findCodesById(String orderId) {
        return warehouseDao.findCodesById(orderId);
    }

    @Override
    public List<OrderEntity> filterListByOrder(List<String> orderList) {
        return orderDao.filterListByOrder(orderList);
    }

    @Override
    public List<OrderEntity> filterListByCode(List<WarehouseEntity> warehouseEntityList) {
        if (warehouseEntityList == null) {
            return Collections.emptyList();
        }
        return orderDao.filterListByCode(warehouseEntityList);
    }

    @Override
    public BaseResponse supplementOrder(String billNo, String orderIdFk) {
        //查询订单数据
        OrderFilterRequest orderFilterRequest = new OrderFilterRequest();
        orderFilterRequest.setId(orderIdFk);
        OrderEntity order = orderDao.findOne(orderFilterRequest);
        //查询此类型单据是否可以补单
        BussinessTypeEntity bussinessTypeEntity = bussinessTypeDao.selectByAction(order.getAction());
        if (StrUtil.isBlank(bussinessTypeEntity.getSupplementOrderType())) {
            //此类型单据不可补单
            return ResultVOUtils.error(ResultEnum.valueOf("此类型单据不可补单"));
        }


        OrderEntity supplementOrder = new OrderEntity();
        BeanUtil.copyProperties(order, supplementOrder);
        //生成补单单号
        String supplementOrderNo = "SM" + CustomUtil.getId();
        supplementOrder.setSupplementNo(order.getId());
        supplementOrder.setId(supplementOrderNo);


        //修改状态
        SystemParamConfigEntity systemParamConfigEntity = systemParamConfigService.selectByParamKey("additional_auto_submit");
        if ("1".equals(systemParamConfigEntity.getParamValue())) {
            supplementOrder.setStatus(ConstantStatus.ORDER_STATUS_PROCESS);        //设置状态为补录单据
        } else {
            supplementOrder.setStatus(ConstantStatus.ORDER_STATUS_ADDITIONAL);        //设置状态为补录单据
        }

        supplementOrder.setExportStatus(0);  //设置导出状态为未导出
        supplementOrder.setContrastStatus(0);//设置erp校验状态为未校验
        supplementOrder.setReceiveStatus(0); //设置验收状态为未验收

        //修改往来单位及当前库存号
        supplementOrder.setFromCorpId(order.getLocStorageCode());
        supplementOrder.setLocStorageCode(order.getFromCorpId());
        String name = invWarehouseDao.getNameByCode(supplementOrder.getFromCorpId());
        supplementOrder.setFromCorp(name);
        supplementOrder.setFromType(ConstantStatus.FROM_PEACE_CHANGE);

        BussinessTypeEntity supplementType = bussinessTypeDao.selectByAction(bussinessTypeEntity.getSupplementOrderType());
        supplementOrder.setMainAction(supplementType.getMainAction());
        supplementOrder.setAction(supplementType.getAction());

//        String time = DateUtil.getBeforeMinute(supplementOrder.getActDate(), 5);
//        supplementOrder.setActDate(time);

        //复制码表
        List<WarehouseEntity> codes = codesDao.findByReceiptId(order.getId());
        List<WarehouseEntity> supplementCodes = new ArrayList<>();
        codes.forEach(
                code -> {
                    WarehouseEntity supplementCode = new WarehouseEntity();
                    BeanUtil.copyProperties(code, supplementCode);
                    supplementCode.setFromCorpId(supplementOrder.getFromCorpId());
                    supplementCode.setFromCorp(supplementOrder.getFromCorp());
                    supplementCode.setLocStorageCode(supplementOrder.getLocStorageCode());
                    supplementCode.setOrderId(supplementOrderNo);
                    //查询补单设置
                    supplementCode.setAction(bussinessTypeEntity.getSupplementOrderType());
                    supplementCode.setMainAction(supplementType.getMainAction());
                    supplementCode.setId(null);
                    supplementCodes.add(supplementCode);

                }
        );
        //更新数据
        try {
            orderDao.insertOrder(supplementOrder);
            //更新配货单表对应单据的补单单号
            stockOrderDao.updateSupplementNoByBillNo(billNo, supplementOrderNo);
            codesTempDao.insertCodesTemp(supplementCodes);
        } catch (Exception e) {
            log.error("补单数据插入失败");
        }
        return ResultVOUtils.success();
    }

    @Override
    public List<StockOrderResponse> checkSupplementOrder(List<StockOrderEntity> stockOrderEntityList) {
        if (CollUtil.isEmpty(stockOrderEntityList)) {
            return Collections.emptyList();
        }
        List<StockOrderResponse> result = new ArrayList<>();
        stockOrderEntityList.forEach(stockOrderEntity -> {
            StockOrderResponse response = new StockOrderResponse();
            BeanUtil.copyProperties(stockOrderEntity, response);
            String supplementOrderType = bussinessTypeDao.selectEnableSupplementOrder(stockOrderEntity.getOrderIdFk());
            if (StrUtil.isBlank(supplementOrderType) || StrUtil.isNotBlank(stockOrderEntity.getSupplementNo())) {
                response.setEnableSupplementOrder(false);
            } else {
                response.setEnableSupplementOrder(true);
            }
            result.add(response);
        });
        return result;
    }


}
