package com.glxp.udi.admin.util;

import cn.hutool.core.util.StrUtil;
import cn.hutool.http.HttpRequest;
import cn.hutool.json.JSONUtil;
import com.alibaba.fastjson.JSON;
import com.glxp.udi.admin.req.feign.BaseParam;
import com.glxp.udi.admin.req.udidl.SysRoleParam;
import com.glxp.udi.admin.req.udidl.SysUserParam;
import com.glxp.udi.common.res.BaseResponse;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;

@Slf4j
@Component
public class UdidlClient {

    @Value("${UDI_SERVER.url}")
    private String url;

    @Value("${UDI_SERVER.connectTimeout}")
    private String connectTimeout;

    @Value("${UDI_SERVER.readTimeout}")
    private String readTimeout;

    @Value("${UDI_SERVER.followRedirects}")
    private String followRedirects;

    @Value("${UDI_SERVER.key}")
    private String key;

    /**
     * 获取生产企业列表
     *
     * @param baseParam
     * @return
     */
    public BaseResponse getManufactureList(BaseParam baseParam) {
        String response = HttpRequest.post(url + "/udplat/manufacture/list")
                .body(JSONUtil.toJsonStr(baseParam))
                .header("key", key)
                .header("connectTimeout", connectTimeout)
                .header("readTimeout", readTimeout)
                .header("followRedirects", followRedirects)
                .execute()
                .body();
        if (StrUtil.isNotBlank(response)) {
            return JSONUtil.toBean(response, BaseResponse.class);
        }
        return null;
    }

    /**
     * 获取配送企业列表
     *
     * @param baseParam
     * @return
     */
    public BaseResponse getDistributorList(BaseParam baseParam) {
        String response = HttpRequest.post(url + "/udplat/distributor/list")
                .body(JSONUtil.toJsonStr(baseParam))
                .header("key", key)
                .header("connectTimeout", connectTimeout)
                .header("readTimeout", readTimeout)
                .header("followRedirects", followRedirects)
                .execute()
                .body();
        if (StrUtil.isNotBlank(response)) {
            return JSONUtil.toBean(response, BaseResponse.class);
        }
        return null;
    }

    /**
     * 获取医疗机构列表
     *
     * @param baseParam
     * @return
     */
    public BaseResponse getHospitalList(BaseParam baseParam) {
        String response = HttpRequest.post(url + "/udplat/hospital/list")
                .body(JSONUtil.toJsonStr(baseParam))
                .header("key", key)
                .header("connectTimeout", connectTimeout)
                .header("readTimeout", readTimeout)
                .header("followRedirects", followRedirects)
                .execute()
                .body();
        if (StrUtil.isNotBlank(response)) {
            return JSONUtil.toBean(response, BaseResponse.class);
        }
        return null;
    }

    /**
     * 查询用户列表
     *
     * @param sysUserParam
     * @return
     */
    public BaseResponse getSysUserList(SysUserParam sysUserParam) {
        String response = HttpRequest.post(url + "/sys/user/list")
                .body(JSONUtil.toJsonStr(sysUserParam))
                .header("key", key)
                .header("connectTimeout", connectTimeout)
                .header("readTimeout", readTimeout)
                .header("followRedirects", followRedirects)
                .execute()
                .body();
        BaseResponse baseResponse = JSON.parseObject(response, BaseResponse.class);
        return baseResponse;
    }

    /**
     * 查询角色列表
     *
     * @param sysRoleParam
     * @return
     */
    public BaseResponse getSysRoleList(SysRoleParam sysRoleParam) {
        String response = HttpRequest.post(url + "/sys/role/list")
                .body(JSONUtil.toJsonStr(sysRoleParam))
                .header("key", key)
                .header("connectTimeout", connectTimeout)
                .header("readTimeout", readTimeout)
                .header("followRedirects", followRedirects)
                .execute()
                .body();
        BaseResponse baseResponse = JSON.parseObject(response, BaseResponse.class);
        return baseResponse;
    }
}
